#!/bin/bash

set -e #< Stop on first error.

source "/opt/networkoptix-metavms/mediaserver/build_info.txt"
FULL_VERSION="$fullVersion"

CRASH_DIR="/opt/networkoptix-metavms/mediaserver/var/crash"

MEDIASERVER_BIN="/opt/networkoptix-metavms/mediaserver/bin/mediaserver"
MEDIASERVER_ARGS="-e --crash-directory=/opt/networkoptix-metavms/mediaserver/var/crash"

process_core_dumps_async() {
    BIN_PATH=$1
    CRASH_DIR=${2:-$HOME}
    FULL_VERSION=${3:-"no-version"}

    if [[ -z $BIN_PATH ]]
    then
        echo "Usage: process_core_dumps_async BINARY_PATH [CRASH_DIR]" >&2
        return 2
    fi

    if ! which gdb
    then
        echo "GDB is not available on the host." >&2
        return 0
    fi

    if pidof gdb
    then
        echo "GDB is already engaged." >&2
        return 0
    fi

    CORE_ORIG=$(dirname "$BIN_PATH")/core
    TIME=$(date +"%s")
    CORE="$CORE_ORIG.$TIME"

    if mv "$CORE_ORIG" "$CORE" 2>/dev/null
    then
        REPORT="$(basename "$BIN_PATH")_${FULL_VERSION}_$TIME.gdb-bt"

        echo "Generate crash report $CRASH_DIR/$REPORT...   BACKGROUND"
        (
            echo "t apply all bt 25" | gdb "$BIN_PATH" "$CORE" &>"/tmp/$REPORT"
            mkdir -p "$CRASH_DIR"
            chmod -R 777 "$CRASH_DIR"
            mv "/tmp/$REPORT" "$CRASH_DIR/$REPORT"
        ) &

        ls "$CORE_ORIG".* | grep -v "$CORE" | xargs rm 2>/dev/null
    fi
}

process_core_dumps_async "$MEDIASERVER_BIN" "$CRASH_DIR" "$FULL_VERSION"

exec "$MEDIASERVER_BIN" $MEDIASERVER_ARGS
